==> haskell-dense-linear-algebra-0.1.0.0-292-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-6QW0xrytE6yASpA72keH6D
key:                  dense-linear-algebra-0.1.0.0-6QW0xrytE6yASpA72keH6D
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  9fac502e519cf4576b96bb977131d0b0
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-6QW0xrytE6yASpA72keH6D
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    math-functions-0.3.4.4-7uKr1CYIpr27fpNWRZfVnW
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh
    vector-algorithms-0.9.0.1-7mOxZsDPWni7UYxG4zDshx
    vector-binary-instances-0.2.5.2-13LhSJzXnNj8yrqiPi7Bkn
    vector-th-unbox-0.2.2-BShAP2Tfez2EbXAT1yBlzM

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-302-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-FEIeLGNxE844Rk0YxApBI8
key:                  dense-linear-algebra-0.1.0.0-FEIeLGNxE844Rk0YxApBI8
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  d823756b13027380b876e037219c251f
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-FEIeLGNxE844Rk0YxApBI8
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    math-functions-0.3.4.4-bJIbxJm3ZnEvmNU4NREUw
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    vector-algorithms-0.9.0.2-DinaOLJn9F3JWEEZxX4tUv
    vector-binary-instances-0.2.5.2-JbK0GaywNsMEVgxrIlAP6k
    vector-th-unbox-0.2.2-2HqVeJvpYiJL8waXQQzuuI

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
